package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.dto.ModuleInfoDTO;
import com.diagbot.dto.QuestionModuleInfoDTO;
import com.diagbot.entity.ModuleInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.service.impl.ModuleInfoServiceImpl;
import com.diagbot.util.ListUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.ModuleDetaillVO;
import com.diagbot.vo.ModuleInfoVO;
import com.google.common.collect.Lists;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author dsYun
 * @Description: 问诊模板
 * @date 2024年11月1日
 */
@Component
public class ModuleInfoFacade extends ModuleInfoServiceImpl {

    /**
     * 获取问诊模板
     *
     * @return 获取问诊模板
     */
    public List<ModuleInfoDTO> getModuleInfo() {
        List<ModuleInfoDTO> retList = Lists.newLinkedList();

        QueryWrapper<ModuleInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey());
        List<ModuleInfo> moduleInfoList = this.list(queryWrapper);

        if (ListUtil.isEmpty(moduleInfoList)) {
            return retList;
        }

        for (ModuleInfo moduleInfo : moduleInfoList) {
            ModuleInfoDTO data = new ModuleInfoDTO();
            data.setId(moduleInfo.getId());
            data.setName(moduleInfo.getName());
            retList.add(data);
        }
        return retList;
    }

    /**
     * 根据问诊id获取内容
     *
     * @return 根据问诊id获取内容演示
     */
    public Map<String, List<QuestionModuleInfoDTO>> getModuleById(ModuleInfoVO moduleInfoVO) {
        Map<String, List<QuestionModuleInfoDTO>> map = new HashMap<>();
        List<QuestionModuleInfoDTO> list1 = new ArrayList<>();
        List<QuestionModuleInfoDTO> list2 = new ArrayList<>();
        if (moduleInfoVO.getId().contains("1") && moduleInfoVO.getId().contains("2") && !moduleInfoVO.getId().contains("12")) {
            moduleInfoVO.setId(null);
        }
        List<QuestionModuleInfoDTO> moduleById = this.getModuleByIds(moduleInfoVO);
        if (ListUtil.isEmpty(moduleById)) {
            return map;
        }
        for (QuestionModuleInfoDTO questionModuleInfoDTO : moduleById) {
            if (questionModuleInfoDTO.getModeId() == 1) {
                list1.add(questionModuleInfoDTO);
            }
            if (questionModuleInfoDTO.getModeId() == 2) {
                list2.add(questionModuleInfoDTO);
            }
        }
        map.put("咳嗽", list1);
        map.put("咳痰", list2);
        return map;
    }

    /**
     * 生成问诊内容
     *
     * @return 生成问诊内容
     */
    public Map<String, String> createContent(ModuleDetaillVO moduleDetaillVO) {
        Map<String, String> map = new HashMap<>();
        StringBuilder chiefSb = new StringBuilder(); //主诉成文
        StringBuilder symptomSb = new StringBuilder(); //现病史成文
        StringBuilder coughTimeStr = new StringBuilder(); //咳嗽主时间
        StringBuilder coughAggravateTimeStr = new StringBuilder(); //咳嗽加重时间
        StringBuilder sputumTimeStr = new StringBuilder(); //咳痰主时间
        StringBuilder sputumAggravateTimeStr = new StringBuilder(); //咳痰加重时间
        //咳嗽主时间
        if (StringUtil.isNotBlank(moduleDetaillVO.getCoughTime()) && !"0".equals(moduleDetaillVO.getCoughTime()) && StringUtil.isNotBlank(moduleDetaillVO.getCoughTimeUnit())) {
            coughTimeStr.append(moduleDetaillVO.getCoughTime() + moduleDetaillVO.getCoughTimeUnit());
        }

        //咳嗽加重时间
        if (StringUtil.isNotBlank(moduleDetaillVO.getCoughAggravateTime()) && !"0".equals(moduleDetaillVO.getCoughAggravateTime()) && StringUtil.isNotBlank(moduleDetaillVO.getCoughAggravateUnit())) {
            coughAggravateTimeStr.append(moduleDetaillVO.getCoughAggravateTime() + moduleDetaillVO.getCoughAggravateUnit());
        }

        //咳痰主时间
        if (StringUtil.isNotBlank(moduleDetaillVO.getSputumTime()) && !"0".equals(moduleDetaillVO.getSputumTime()) && StringUtil.isNotBlank(moduleDetaillVO.getSputumTimeUnit())) {
            sputumTimeStr.append(moduleDetaillVO.getSputumTime() + moduleDetaillVO.getSputumTimeUnit());
        }

        //咳痰加重时间
        if (StringUtil.isNotBlank(moduleDetaillVO.getSputumAggravateTime()) && !"0".equals(moduleDetaillVO.getSputumAggravateTime()) && StringUtil.isNotBlank(moduleDetaillVO.getSputumAggravateTimeUnit())) {
            sputumAggravateTimeStr.append(moduleDetaillVO.getSputumAggravateTime() + moduleDetaillVO.getSputumAggravateTimeUnit());
        }

        //存在咳嗽和咳痰
        if (StringUtil.isNotBlank(coughTimeStr.toString()) && StringUtil.isNotBlank(sputumTimeStr.toString()) && StringUtil.isNotBlank(coughAggravateTimeStr.toString()) && StringUtil.isNotBlank(sputumAggravateTimeStr.toString())) {
            if (coughTimeStr.toString().equals(sputumTimeStr.toString()) && coughAggravateTimeStr.toString().equals(sputumAggravateTimeStr.toString())) {
                chiefSb.append("咳嗽、咳痰" + coughTimeStr.toString() + "，加重" + coughAggravateTimeStr.toString() + "。");
            } else if (coughTimeStr.toString().equals(sputumTimeStr.toString()) && !coughAggravateTimeStr.toString().equals(sputumAggravateTimeStr.toString())) {
                chiefSb.append("咳嗽、咳痰" + coughTimeStr.toString() + "，加重" + coughAggravateTimeStr.toString() + "，加重" + sputumAggravateTimeStr.toString() + "。");
            } else if (!coughTimeStr.toString().equals(sputumTimeStr.toString()) && !coughAggravateTimeStr.toString().equals(sputumAggravateTimeStr.toString())) {
                chiefSb.append("咳嗽" + coughTimeStr.toString() + "，加重" + coughAggravateTimeStr.toString() + "，咳痰" + sputumTimeStr.toString() + "，加重" + sputumAggravateTimeStr.toString() + "。");
            }
        } else if (StringUtil.isNotBlank(coughTimeStr.toString()) && StringUtil.isNotBlank(coughAggravateTimeStr.toString()) && StringUtil.isBlank(sputumTimeStr.toString())) {
            chiefSb.append("咳嗽" + coughTimeStr.toString() + "，加重" + coughAggravateTimeStr.toString() + "。");
        } else if (StringUtil.isNotBlank(coughTimeStr.toString()) && StringUtil.isBlank(coughAggravateTimeStr.toString()) && StringUtil.isBlank(sputumTimeStr.toString())) {
            chiefSb.append("咳嗽" + coughTimeStr.toString() + "。");
        }
        if (StringUtil.isNotBlank(chiefSb.toString())) {
            map.put("主诉", chiefSb.toString());
        }

        if (StringUtil.isNotBlank(coughTimeStr.toString()) && StringUtil.isNotBlank(sputumTimeStr.toString())) {
            if (coughTimeStr.toString().equals(sputumTimeStr.toString())) {
                symptomSb.append(coughTimeStr.toString() + "前" + isNull(moduleDetaillVO.getCoughCause()) + "出现咳嗽、咳痰。咳嗽呈" + isNull(moduleDetaillVO.getCoughNature()) + isNull(moduleDetaillVO.getCoughDegree())
                        + "伴有" + isNull(moduleDetaillVO.getCoughAccompanyingSymptoms()) + "，咳痰呈" + isNull(moduleDetaillVO.getSputumParoxysm()) + "，" + isNull(moduleDetaillVO.getSputumColour()) + isNull(moduleDetaillVO.getSputumNature())
                        + "，" + isNull(moduleDetaillVO.getSputumAmount()) + "，每次可咳约" + isNull(moduleDetaillVO.getSputumSpecificAmount()) + "ml，一天总共可咳约" + isNull(moduleDetaillVO.getSputumSpecificAmountDay()) + "ml，"
                        + isNull(moduleDetaillVO.getSputumIsUnobstructed()) + "，伴有" + isNull(moduleDetaillVO.getSputumAccompanyingSymptoms() + "。")
                );
            } else {
                symptomSb.append(coughTimeStr.toString() + "前" + isNull(moduleDetaillVO.getCoughCause()) + "出现咳嗽，咳嗽呈" + isNull(moduleDetaillVO.getCoughNature()) + isNull(moduleDetaillVO.getCoughDegree())
                        + isNull(moduleDetaillVO.getCoughAccompanyingSymptoms()) + "。" + sputumTimeStr.toString() + "前" + isNull(moduleDetaillVO.getSputumCause()) + "出现咳痰，咳痰呈" + isNull(moduleDetaillVO.getSputumParoxysm()) + "，" + isNull(moduleDetaillVO.getSputumColour()) + isNull(moduleDetaillVO.getSputumNature())
                        + "，" + isNull(moduleDetaillVO.getSputumAmount()) + "，每次可咳约" + isNull(moduleDetaillVO.getSputumSpecificAmount()) + "ml，一天总共可咳约" + isNull(moduleDetaillVO.getSputumSpecificAmountDay()) + "ml，"
                        + isNull(moduleDetaillVO.getSputumIsUnobstructed()) + "，伴有" + isNull(moduleDetaillVO.getSputumAccompanyingSymptoms() + "。")
                );
            }
        } else if (StringUtil.isNotBlank(coughTimeStr.toString()) && StringUtil.isBlank(sputumTimeStr.toString())) {
            symptomSb.append(coughTimeStr.toString() + "前" + isNull(moduleDetaillVO.getCoughCause()) + "出现咳嗽，咳嗽呈" + isNull(moduleDetaillVO.getCoughNature()) +
                    isNull(moduleDetaillVO.getCoughDegree()) + isNull(moduleDetaillVO.getCoughAccompanyingSymptoms() + "。")
            );
        }

        if (moduleDetaillVO.getId() == 2 && StringUtil.isNotBlank(symptomSb.toString())) {
            map.put("现病史", symptomSb.toString());
        }

        return map;
    }

    /**
     * 判断字段是否为空
     */
    public String isNull(String text) {
        return text == null ? "" : text;
    }

}
